from __future__ import absolute_import
from .emvcs import *

__name__ = "emvcs"
__init__ = [Get()]
__version__ = "2.1"
